==> runtime-management-api-0.3.296-sources.jar: io/cloudslang/runtime/api/python/entities/PythonExecutorDetails.java <==
/*
 * Copyright © 2014-2017 EntIT Software LLC, a Micro Focus company (L.P.)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.cloudslang.runtime.api.python.entities;

public class PythonExecutorDetails {

    private String port;
    private String url;
    private String runtimeEncodedAuth;
    private String lifecycleEncodedAuth;

    public PythonExecutorDetails() {
    }

    public PythonExecutorDetails(String port, String url, String runtimeEncodedAuth, String lifecycleEncodedAuth) {
        this.port = port;
        this.url = url;
        this.runtimeEncodedAuth = runtimeEncodedAuth;
        this.lifecycleEncodedAuth = lifecycleEncodedAuth;
    }

    public String getPort() {
        return port;
    }

    public void setPort(String port) {
        this.port = port;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getRuntimeEncodedAuth() {
        return runtimeEncodedAuth;
    }

    public void setRuntimeEncodedAuth(String runtimeEncodedAuth) {
        this.runtimeEncodedAuth = runtimeEncodedAuth;
    }

    public String getLifecycleEncodedAuth() {
        return lifecycleEncodedAuth;
    }

    public void setLifecycleEncodedAuth(String lifecycleEncodedAuth) {
        this.lifecycleEncodedAuth = lifecycleEncodedAuth;
    }
}

==> runtime-management-api-0.3.315-sources.jar: io/cloudslang/runtime/api/python/entities/PythonExecutorDetails.java <==
/*
 * Copyright © 2014-2017 EntIT Software LLC, a Micro Focus company (L.P.)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.cloudslang.runtime.api.python.entities;

public class PythonExecutorDetails {

    private String port;
    private String url;
    private String runtimeEncodedAuth;
    private String lifecycleEncodedAuth;
    private String sourceLocation;
    private String encodedSecretKeyPath;

    public PythonExecutorDetails() {
    }

    public PythonExecutorDetails(String port, String url, String runtimeEncodedAuth, String lifecycleEncodedAuth, String sourceLocation, String encodedSecretKeyPath) {
        this.port = port;
        this.url = url;
        this.runtimeEncodedAuth = runtimeEncodedAuth;
        this.lifecycleEncodedAuth = lifecycleEncodedAuth;
        this.sourceLocation = sourceLocation;
        this.encodedSecretKeyPath = encodedSecretKeyPath;
    }

    public String getPort() {
        return port;
    }

    public void setPort(String port) {
        this.port = port;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getRuntimeEncodedAuth() {
        return runtimeEncodedAuth;
    }

    public void setRuntimeEncodedAuth(String runtimeEncodedAuth) {
        this.runtimeEncodedAuth = runtimeEncodedAuth;
    }

    public String getLifecycleEncodedAuth() {
        return lifecycleEncodedAuth;
    }

    public void setLifecycleEncodedAuth(String lifecycleEncodedAuth) {
        this.lifecycleEncodedAuth = lifecycleEncodedAuth;
    }

    public String getSourceLocation() {
        return sourceLocation;
    }

    public void setSourceLocation(String sourceLocation) {
        this.sourceLocation = sourceLocation;
    }

    public String getEncodedSecretKeyPath() {
        return encodedSecretKeyPath;
    }

    public void setEncodedSecretKeyPath(String encodedSecretKeyPath) {
        this.encodedSecretKeyPath = encodedSecretKeyPath;
    }
}
